==> patch-2.5.4.12.zip: app/views/login/logout.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form; ?>
<div class="container">
    <div class="row">

    </div>
    <?php if(!isMobile()){?><br/><br/><br/><?php } ?>
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default no-box-shadow">
                <div class="panel-body">
                    <?php if(is_file("/var/www/portal/app/templates/default/collateral/".NEIL_IMG_NAME)){ ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" />
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" />
                            <?php } ?>
                        </div>
                    <?php } else { ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" />
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" />
                            <?php } ?>
                        </div>
                    <?php }?>
                    <div class="col-lg-6" <?php if(!isMobile()){ ?> style="margin-top: 95px;" <?php } ?>>
                        <a><b class="h3" style="word-wrap: break-word;">You have been successfully logged out</b></a>
                        </br>
                        <a class="btn btn-primary" href="<?=DIR?>" style="margin-top: 20px;">Login</a>
                    </div>
                    <div class="col-lg-12">
                            <div class="col-lg-10">
                            <?php if(EULA_ENABLED == true){ ?>
                                <h4 style="font-size:8px;margin-left:50px;">By using all or any portion of the software, you are agreeing to be bound by the terms and conditions of our End User Licensing Agreement and other policies which can be found under <a href="https://www.parablu.com/legal">https://www.parablu.com/legal</a></h4>
                            <?php } ?>
                            <?php
                                if(file_exists('/var/www/portal/app/templates/default/collateral/disclaimer.txt')){
                                    echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                    foreach(file('/var/www/portal/app/templates/default/collateral/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                    }
                                }else{
                                    if(file_exists('/var/www/portal/app/templates/default/images/disclaimer.txt')){
                                        echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                        foreach(file('/var/www/portal/app/templates/default/images/disclaimer.txt') as $line) {
                                            echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                        }
                                    }
                                }
                            ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<script>
localStorage.clear();
</script>

==> patch-2.5.5.0_5.zip: app/views/login/logout.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form; ?>
<div class="container">
    <div class="row">
    </div>
    <?php if(!isMobile()){?><br/><br/><br/><?php } ?>
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default no-box-shadow">
                <div class="panel-body">
                    <?php if(is_file("/var/www/portal/app/templates/default/collateral/".NEIL_IMG_NAME)){ ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php } ?>
                        </div>
                    <?php } else { ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php } ?>
                        </div>
                    <?php }?>
                    <div class="col-lg-6" <?php if(!isMobile()){ ?> style="margin-top: 95px;" <?php } ?>>
                        <a><b class="h3" style="word-wrap: break-word;">You have been successfully logged out</b></a>
                        </br>
                        <a class="btn btn-primary" href="<?=DIR?>" style="margin-top: 20px;">Login</a>
                    </div>
                    <div class="col-lg-12" style="margin-top:20px;">
                            <div class="col-lg-10" style="margin-top:20px;">
                            <?php if(EULA_ENABLED == true){ ?>
                                <h4 style="font-size:8px;margin-left:50px;">By using all or any portion of the software, you are agreeing to be bound by the terms and conditions of our End User Licensing Agreement and other policies which can be found under <a href="https://www.parablu.com/legal">https://www.parablu.com/legal</a></h4>
                            <?php } ?>
                            <?php
                                if(file_exists('/var/www/portal/app/templates/default/collateral/disclaimer.txt')){
                                    echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                    foreach(file('/var/www/portal/app/templates/default/collateral/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                    }
                                }else{
                                    if(file_exists('/var/www/portal/app/templates/default/images/disclaimer.txt')){
                                        echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                        foreach(file('/var/www/portal/app/templates/default/images/disclaimer.txt') as $line) {
                                            echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                        }
                                    }
                                }
                            ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<script>
localStorage.clear();
</script>
